@@ -4,8 +4,8 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
-#include <sys/mman.h>
 #include "lib/mlrutil.h"
+#include "lib/mlrescape.h"
 #include "lib/mlr_globals.h"
 #include "file_reader_stdio.h"
 
@@ -23,17 +23,19 @@ void* file_reader_stdio_vopen(void* pvstate, char* prepipe, char* filename) {
 			}
 		}
 	} else {
-		char* command = mlr_malloc_or_die(strlen(prepipe) + 3 + strlen(filename) + 1);
+		char* escaped_filename = alloc_file_name_escaped_for_popen(filename);
+		char* command = mlr_malloc_or_die(strlen(prepipe) + 3 + strlen(escaped_filename) + 1);
 		if (streq(filename, "-"))
 			sprintf(command, "%s", prepipe);
 		else
-			sprintf(command, "%s < %s", prepipe, filename);
+			sprintf(command, "%s < %s", prepipe, escaped_filename);
 		input_stream = popen(command, "r");
 		if (input_stream == NULL) {
 			fprintf(stderr, "%s: Couldn't popen \"%s\" for read.\n", MLR_GLOBALS.bargv0, command);
 			perror(command);
 			exit(1);
 		}
+		free(escaped_filename);
 		free(command);
 	}
 	return input_stream;
