@@ -85,3 +85,17 @@ $path_to_mlr --json cat <<EOF | run_mlr --json cat
 EOF
 
 
+
+$path_to_mlr --json cat <<EOF | run_mlr --json --jvstack cat
+{"x":[1,[2,[3,4,5],6],7]}
+EOF
+$path_to_mlr --json cat <<EOF | run_mlr --json --no-jvstack cat
+{"x":[1,[2,[3,4,5],6],7]}
+EOF
+
+$path_to_mlr --json cat <<EOF | run_mlr --json --jvstack cat
+{"x":{"a":1,"b":{"c":3,"d":4,"e":5},"f":6},"y":7}
+EOF
+$path_to_mlr --json cat <<EOF | run_mlr --json --no-jvstack cat
+{"x":{"a":1,"b":{"c":3,"d":4,"e":5},"f":6},"y":7}
+EOF
